# We can skip tests.
%bcond_without testsuite

# Language config for different arches / dists.
%ifarch aarch64 %{arm} ppc64le ppc %{power64} s390 s390x
%{!?Rlang:	%global Rlang 0}
%{!?javalang:	%global javalang 0}
%endif # arch aarch64 %%{arm} ppc64le ppc %%{power64} s390 s390x

%if 0%{?rhel} == 0
%{!?Rlang:	%global Rlang 1}
%endif # 0%%{?rhel} == 0

%if 0%{?fedora} || 0%{?rhel} >= 6
%{!?javalang:	%global javalang 1}
%{!?octavelang:	%global octavelang 1}
%endif # 0%%{?fedora} || 0%%{?rhel} >= 7

%if 0%{?fedora} || 0%{?rhel} >= 8
%{!?py3lang:	%global py3lang 1}
%endif # 0%%{?fedora} || 0%%{?rhel} >= 8

%{!?tcllang:	%global tcllang 1}
%{!?guilelang:	%global guilelang 1}

# Original package-name.
%global orig_name swig

# Setup _pkgdocdir if not defined already.
%{!?_pkgdocdir:	%global _pkgdocdir %{_docdir}/%{name}-%{version}}

# Does license.txt go to %%license?
%if 0%{?fedora} >= 21 || 0%{?rhel} >= 8
%global with_license 1
%endif # 0%%{?fedora} >= 21 || 0%%{?rhel} >= 8


Name:		%{orig_name}2
Version:	2.0.12
Release:	4%{?dist}
Summary:	Connects C/C++/Objective C to some high-level programming languages
Group:		Development/Tools

License:	GPLv3+ and BSD
URL:		http://%{orig_name}.sourceforge.net/
Source0:	http://downloads.sourceforge.net/project/%{orig_name}/%{orig_name}/%{orig_name}-%{version}/%{orig_name}-%{version}.tar.gz
Source1:	description.h2m

# Upstream patch to fix guile locale
# https://github.com/swig/swig/pull/139/files
Patch0:		swig-guile.patch
Patch1:		swig207-setools.patch
# Fix the failure on arch x390 during testing
Patch2:		swig-2.0.10-Fix-x390-build.patch
Patch3:		swig-2.0.12_regenerated-autotools.patch

%if 0%{?rhel} && 0%{?rhel} <= 5
BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)}
%endif

%if 0%{?fedora} || 0%{?rhel} >= 6
BuildRequires:	autoconf
BuildRequires:	automake
%endif # 0%%{?fedora} || 0%%{?rhel} >= 6
BuildRequires:	boost-devel
BuildRequires:	dos2unix
%if 0%{?guilelang}
BuildRequires:	guile-devel
%endif # 0%%{?guilelang}
BuildRequires:	hardlink
BuildRequires:	help2man
%if 0%{?javalang}
BuildRequires:	java-devel
%endif # 0%%{?javalang}
%if 0%{?octavelang}
BuildRequires:	octave-devel
%endif # 0%%{?octavelang}
BuildRequires:	pcre-devel
%if 0%{?fedora} || 0%{?rhel} >= 6
BuildRequires:	perl-devel
%endif # 0%%{?fedora} || 0%%{?rhel} >= 6
BuildRequires:	perl(Test::More)
BuildRequires:	python2-devel
%if 0%{?py3lang}
BuildRequires:	python3-devel
%endif # 0%%{?py3lang}
%if 0%{?Rlang}
BuildRequires:	R-devel
%endif # 0%%{?Rlang}
%if 0%{?tcllang}
BuildRequires:	tcl-devel
%endif # 0%%{?tcllang}

Requires:	%{name}-common	== %{version}-%{release}
Provides:	%{orig_name}	== %{version}-%{release}

%description
SWIG is a software development tool that connects programs
written in C and C++ with a variety of high-level programming
languages.  SWIG is used with different types of target
languages including common scripting languages such as
Javascript, Perl, PHP, Python, Tcl and Ruby.  The list of
supported languages also includes non-scripting languages
such as C#, Common Lisp (CLISP, Allegro CL, CFFI, UFFI), D,
Go language, Java including Android, Lua, Modula-3, OCAML,
Octave, Scilab and R.  Also several interpreted and compiled
Scheme implementations (Guile, MzScheme/Racket, Chicken) are
supported.  SWIG is most commonly used to create high-level
interpreted or compiled programming environments, user
interfaces, and as a tool for testing and prototyping C/C++
software.  SWIG is typically used to parse C/C++ interfaces and
generate the 'glue code' required for the above target languages
to call into the C/C++ code.  SWIG can also export its parse
tree in the form of XML and Lisp s-expressions.  SWIG is free
software and the code that SWIG generates is compatible with
both commercial and non-commercial projects.


%package devel
Summary:	Common files used by SWIG to generate C-sources
Group:		Development/Tools
License:	GPLv3+ and BSD

%if 0%{?fedora} || 0%{?rhel} >= 6
BuildArch:	noarch
%endif # 0%%{?fedora} || 0%%{?rhel} >= 6

Requires:	%{name}		== %{version}-%{release}
Provides:	%{name}-common	== %{version}-%{release}

%description devel
This package contains common files used by SWIG to generate C-sources.


%package doc
Summary:	Documentation files for SWIG
Group:		Documentation
License:	GPLv3+ and BSD

%if 0%{?fedora} || 0%{?rhel} >= 6
BuildArch:	noarch
%endif # 0%%{?fedora} || 0%%{?rhel} >= 6

%description doc
This package contains documentation for SWIG and useful examples.


%prep
%setup -qn %{orig_name}-%{version}

%patch0 -p1 -b .guile
%patch1 -p1 -b .setools
%patch2 -p1 -b .x390

# Regenerate autocrap.
%if 0%{?fedora} || 0%{?rhel} >= 6
./autogen.sh
%else # 0%%{?fedora} || 0%%{?rhel} >= 6
%patch3 -p1 -b .autotools
%endif # 0%%{?fedora} || 0%%{?rhel} >= 6

# Charset conversion.
for all in CHANGES README
do
	%{_bindir}/iconv -f ISO88591 -t UTF8 < $all > $all.new
	/bin/touch -r $all $all.new
	%{__mv} -f $all.new $all
done

# Make ccache-swig aware of being renamed, so it works properly.
%{__sed} -i -e 's!#define MYNAME .*!#define MYNAME "ccache-%{name}"!'	\
	CCache/ccache.h
%{__sed} -i -e 's!CCACHE=\.\./ccache-%{orig_name}!&2!' CCache/test.sh


%build
# Disable maximum compile warnings when octave is supported, because Octave
# code produces lots of the warnings demanded by strict ISO C and ISO C++.
# It causes that log had more then 600M.
%configure								\
	--without-ocaml							\
%if 0%{?javalang} == 0
	--without-java							\
%endif # 0%%{?javalang} == 0
%if 0%{?Rlang} == 0
	--without-r							\
%endif # 0%%{?Rlang} == 0
%if 0%{?octavelang}
	--with-octave=%{_bindir}/octave					\
	--without-maximum-compile-warnings				\
%endif # 0%%{?octavelang}
;

%{__make} %{?_smp_mflags}


%install
%if 0%{?rhel} && 0%{?rhel} <= 5
%{__rm} -rf %{buildroot}
%endif # 0%%{?rhel} && 0%%{?rhel} <= 5

# Remove all arch dependent files in Examples/ created during tests.
%{__make} clean-examples

# Install documentation-files in unified %%{_pkgdocdir}.
%{__mkdir} -p	%{buildroot}%{_pkgdocdir}
%{__cp} -a	ANNOUNCE CHANGES CHANGES.current COPYRIGHT Doc Examples	\
		LICENSE* README RELEASENOTES TODO %{buildroot}%{_pkgdocdir}

# Remove duplicated files, if they get picked up by %%license.
%if 0%{?with_license}
%{__rm} -f %{buildroot}%{_pkgdocdir}/{COPYRIGHT,LICENSE*}
%endif # 0%%{?with_license}

# Hardlink files in %%{_pkgdocdir}, saves about 2 MBytes.
%{_sbindir}/hardlink -v %{buildroot}%{_pkgdocdir}

pushd %{buildroot}%{_pkgdocdir}/Examples/
# Remove all arch dependent files in Examples/.
%{_bindir}/find -type f -name 'Makefile*' -delete -print

# We don't want to ship files below.
%{__rm} -rf test-suite
%{_bindir}/find -type f -name '*.dsp' -delete -print
%{_bindir}/find -type f -name '*.dsw' -delete -print

# Convert files to UNIX format.
%{_bindir}/find -type f -print0 | xargs -0 dos2unix -k
%{_bindir}/find -type f -print0 | xargs -0 chmod -c 0644
popd

%{__make} DESTDIR=%{buildroot} install

# Use help output for generating of man page.
echo "Options:" > help_output
%{buildroot}%{_bindir}/swig --help >> help_output

# Update the output to be correctly formatted be help2man.
%{__sed} -i -e 's/^\(\s\+-[^-]\+\)- \(.*\)$/\1 \2/' help_output
%{__sed} -i -e 's/^\(\s\+-\w\+-[^-]*\)- \(.*\)$/\1 \2/' help_output

# Generate a helper script that will be used by help2man.
%{__cat} > h2m_helper << 'EOF'
#!/bin/bash
[ "$1" == "--version" ] && echo "" || cat help_output
EOF
%{__chmod} 0755 h2m_helper

# Generate man page.
%{_bindir}/help2man	-N --section 1 ./h2m_helper			\
			--include %{SOURCE1} -o %{name}.1

# Add man page for swig to repository.
%{__mkdir} -p %{buildroot}%{_mandir}/man1/
%{__install} -pm 0644 %{name}.1 %{buildroot}%{_mandir}/man1/

# Enable ccache-swig by default, if ccache is installed.
%{__mkdir} -p %{buildroot}%{_libdir}/ccache
/bin/ln -fs ../../bin/ccache-%{name} %{buildroot}%{_libdir}/ccache/%{name}

# Get rid of 0-size rpmlint-warning.
for _file in $(find %{buildroot}%{_datadir}/%{name} -size 0 -type f); do
	echo "// empty" > $_file.new
	/bin/touch -r $_file $_file.new
	%{__mv} -f $_file.new $_file
done

# Rename the files in %%{buildroot}%%{_bindir}.
for _file in %{buildroot}%{_bindir}/*%{orig_name}
do
	%{__mv} -f ${_file} ${_file}2
done
%{__mv} -f	%{buildroot}%{_mandir}/man1/ccache-%{orig_name}.1	\
		%{buildroot}%{_mandir}/man1/ccache-%{name}.1


%check
%if %{with testsuite}
# Rename ccache-swig properly.
%{__mv} -f CCache/ccache-%{orig_name} CCache/ccache-%{name}
# Run test-suite.
%{__make} check
# Revert 'Rename ccache-swig properly.'.
%{__mv} -f CCache/ccache-%{name} CCache/ccache-%{orig_name}
%endif


%if 0%{?rhel} && 0%{?rhel} <= 5
%clean
%{__rm} -rf %{buildroot}
%endif # 0%%{?rhel} && 0%%{?rhel} <= 5


%files
%{_bindir}/*%{name}
%{_libdir}/ccache
%{_mandir}/man1/*%{name}.1*
%doc %dir %{_pkgdocdir}
%doc %{_pkgdocdir}/README
%if 0%{?with_license}
%license COPYRIGHT
%license LICENSE
%license LICENSE-GPL
%license LICENSE-UNIVERSITIES
%else # 0%%{?with_license}
%doc %{?_pkgdocdir}/COPYRIGHT
%doc %{?_pkgdocdir}/LICENSE
%doc %{?_pkgdocdir}/LICENSE-GPL
%doc %{?_pkgdocdir}/LICENSE-UNIVERSITIES
%endif # 0%%{?with_license}

%files devel
%{_datadir}/%{orig_name}
%doc %dir %{_pkgdocdir}
%doc %{_pkgdocdir}/ANNOUNCE
%doc %{_pkgdocdir}/CHANGES
%doc %{_pkgdocdir}/CHANGES.current
%doc %{_pkgdocdir}/RELEASENOTES
%doc %{_pkgdocdir}/TODO

%files doc
%doc %{_pkgdocdir}
%if 0%{?with_license}
%license COPYRIGHT
%license LICENSE
%license LICENSE-GPL
%license LICENSE-UNIVERSITIES
%endif # 0%%{?with_license}


%changelog
* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.12-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 2.0.12-3
- Rebuilt for GCC 5 C++11 ABI change

* Fri Apr 03 2015 Björn Esser <bjoern.esser@gmail.com> - 2.0.12-2
- make ccache-swig aware of being renamed, so it works properly

* Wed Apr 01 2015 Björn Esser <bjoern.esser@gmail.com> - 2.0.12-1
- initial rpm release (#1208217)
- based on spec-file taken from fedora scm swig-pkg @b1604a3cc8b0
